@@ -21,6 +21,10 @@ import os
 from gluon.html import DIV, URL, H2, FORM, LABEL, P, XML, OL, LI
 from gluon.utils import hash
 
+STRFTIME = {
+    'time_date': '%I:%M %p %d-%m-%Y',
+}
+
 def gURL(request):
     def _URL(*args, **kwargs):
         if kwargs.has_key('r'):
@@ -132,6 +136,19 @@ def ws(q):
     ws = '%'.join(qs.lower() for qs in q.split(' '))
     return w(ws)
 
+def decode_phone(phone):
+    decoded = ""
+    for char in phone:
+        if char >= "0" and char <= "9":
+            decoded += char
+    return decoded
+   
+def encode_phone(phone):
+    if len(phone) == 10:
+        return '(' + phone[0:3] + ') ' + phone[3:6] + '-' + phone[6:]
+    else:
+        return ''
+
 def generate_uuid(record, digest_alg='sha512'):
     """
     Generates a unique identifer for the record
